Welcome to njets's documentation!
=================================

`njet` is a lightweight AD package, using forward-mode automatic differentiation, in order to determine the
higher-order derivatives of a given function in multiple variables.

Latest version: |release|

.. toctree::
   :maxdepth: 2
   :caption: Contents:

   README.md

   ad.rst
   jet.rst
   poly.rst
   extras.rst
   functions.rst


Indices and tables
==================

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

